<?php
/**
 * Set ahead layout according to options
 *
 * @package Ahead
 */

defined( 'WPINC' ) || exit;

/**
 * Layout manager.
 */
class Ahead_Layout extends Ahead_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'ahead_before_wrapper', 'add_header' );
		$this->add_action( 'ahead_single_post_full_header', 'single_post_full_header' );
		$this->add_action( 'ahead_single_post_header_thumb', 'single_post_header_thumb' );
		$this->add_action( 'ahead_breadcrumb_lists', 'breadcrumb_lists' );
		$this->add_action( 'ahead_before_footer', 'full_related_posts' );
	}

	/**
	 * Add header
	 */
	public function add_header() {
		$hash   = array(
			'header-default' => 'default',
			'header-layout2' => 'layout2',
		);
		$layout = ahead_get_settings( 'header_styles' );
		get_template_part( 'template-parts/header/header', isset( $hash[ $layout ] ) ? $hash[ $layout ] : $layout );
	}

	/**
	 * Single post header thumbnail
	 */
	public function single_post_header_thumb() {
		$img_size         = ahead_get_settings( 'featured_image_size' );
		$header_animation = ahead_get_post_header_effect();
		if ( 'default' === $img_size ) :
			ahead_single_featured_image_effect();
			if ( ! $header_animation && ahead_get_settings( 'show_single_featured' ) ) {
				$attr = [
					'class'   => 'single-featured-image',
					'title'   => esc_attr( get_the_title() ),
					'alt'     => esc_attr( get_the_title() ),
					'loading' => 'lazy',
				];
				the_post_thumbnail( 'ahead-single-featured', $attr );
			}
			?>
			<header>
				<?php
				if ( ahead_get_settings( 'single_category_post' ) ) :
					printf( '<div class="thecategory">%s</div>', ahead_get_the_category( ' ' ) );
				endif;
				?>
				<h1 class="single-title"><?php the_title(); ?></h1>
				<?php ahead_the_post_meta( 'single' ); ?>
			</header>
			<?php
		endif;

	}

	/**
	 * Single post header if fullwidth layout
	 */
	public function single_post_full_header() {
		$img_size         = ahead_get_settings( 'featured_image_size' );
		$header_animation = ahead_get_post_header_effect();
		if ( 'full' === $img_size ) :
			if ( have_posts() ) :
				while ( have_posts() ) :
					the_post();
					global $post;
					$featured_image = array();
					if ( ahead_get_settings( 'show_single_featured' ) ) {
						if ( has_post_thumbnail() ) {
							$featured_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'ahead-full-header' );
						} else {
							$nothumb = get_parent_theme_file_uri() . '/images/nothumb-ahead-full-header.png';
						}
					}
					if ( 'parallax' === $header_animation && has_post_thumbnail() ) {
						echo '<header id="parallax" class="single-full-header clearfix" style="background-image: url(' . get_the_post_thumbnail_url( get_the_ID(), 'full' ) . ');">';
					} elseif ( 'zoomout' === $header_animation && has_post_thumbnail() ) {
						echo '<header id="zoom-out-effect"><div id="zoom-out-bg" style="background-image: url(' . get_the_post_thumbnail_url( get_the_ID(), 'full' ) . ');">';
					} else {
						?>
						<header class="single-full-header clearfix" style="background-image: url('<?php echo has_post_thumbnail() ? $featured_image[0] : $nothumb; ?>');">
						<?php
					}
					if ( ahead_get_settings( 'show_prev_next' ) ) {
						?>
						<div class="prev-next">
							<?php
							previous_post_link( '<div class="prev">%link</div>', '<i class="fa fa-angle-left"></i>', true );
							next_post_link( '<div class="next">%link</div>', '<i class="fa fa-angle-right"></i>', true );
							?>
						</div>
						<?php
					}
					?>
					<div class="single-full-header-content">
						<div class="container">
							<div class="full-header-wrapper clearfix">
								<?php
								if ( ahead_get_settings( 'single_category_post' ) ) :
									printf( '<div class="thecategory">%s</div>', ahead_get_the_category( ' ' ) );
								endif;
								?>
								<h1 class="single-title"><?php the_title(); ?></h1>
								<?php ahead_the_post_meta( 'single' ); ?>
							</div>
						</div>
					</div>
					<?php
					if ( 'zoomout' === $header_animation && has_post_thumbnail() ) :
						echo '</div>';
					endif;
					?>
				</header>
					<?php
				endwhile;
			endif; /* end loop */
		endif;
	}

	/**
	 * Breadcrumb
	 */
	public function breadcrumb_lists() {
		echo '<div class="breadcrumb-wrapper clearfix">';
		echo '<div class="container">';
		ahead_breadcrumbs();
		echo '</div>';
		echo '</div>';
	}

	/**
	 * Single post related posts
	 */
	public function full_related_posts( $position = 'full' ) {
		if ( 'full' === ahead_get_settings( 'related_posts_position' ) ) {
			ahead_related_posts();
		}
	}

}

// Init.
new Ahead_Layout;
