<?php
/**
 * Script enqueueing manager.
 *
 * @package Ahead
 */

defined( 'WPINC' ) || exit;

/**
 * Script enqueueing manager.
 */
class Ahead_Scripts extends Ahead_Base {

	/**
	 * The Constructor
	 */
	public function __construct() {

		if ( ! is_admin() && ! in_array( $GLOBALS['pagenow'], array( 'wp-login.php', 'wp-register.php' ) ) ) {

			$this->add_action( 'wp_enqueue_scripts', 'enqueue_scripts' );

			if ( ahead_get_settings( 'optimize_wc' ) ) {

				$this->add_action( 'wp_enqueue_scripts', 'remove_woocommerce_scripts', 99 );

				// Remove WooCommerce generator tag.
				remove_action( 'wp_head', 'wc_generator_tag' );
			}

			if ( ahead_get_settings( 'async_js' ) ) {
				$this->add_filter( 'script_loader_tag', 'add_async', 10, 2 );
			}

			if ( ahead_get_settings( 'remove_ver_params' ) ) {
				$this->add_filter( 'script_loader_src', 'remove_version', 99 );
				$this->add_filter( 'style_loader_src', 'remove_version', 99 );
			}
		}
	}

	/**
	 * Takes care of enqueueing all our scripts.
	 */
	public function enqueue_scripts() {
		$this->styles();
		$this->scripts();
	}

	/**
	 * Enqueue CSS files
	 */
	private function styles() {
		$version            = ahead()->get_version();
		$template_directory = get_template_directory_uri();

		// style.css file.
		wp_enqueue_style( 'ahead-theme', $template_directory . '/style.css', array(), $version );

		$deps = 'ahead-theme';

		// Font Awesome.
		$this->font_styles();
		wp_enqueue_style( 'fontawesome', $template_directory . '/css/font-awesome.min.css', $deps, '4.7.0' );

		// Slider.
		wp_register_style( 'owl-carousel', $template_directory . '/css/owl.carousel.css', $deps, $version );

		// Responsive.
		if ( ahead_get_settings( 'mts_responsive', false ) ) {
			wp_enqueue_style( 'ahead-responsive', $template_directory . '/css/ahead-responsive.css', $deps, $version );
		}

		// WooCommerce.
		if ( ahead_is_woocommerce_active() ) {
			wp_enqueue_style( 'ahead-woocommerce', $template_directory . '/css/ahead-woocommerce.css', 'woocommerce', $version );
		}

		// Lightbox.
		if ( ahead_get_settings( 'enable_lightbox' ) ) {
			wp_enqueue_style( 'magnificPopup', $template_directory . '/css/magnific-popup.css', $deps, $version );
		}

	}

	/**
	 * Enqueue JS files
	 */
	private function scripts() {

		$version            = ahead()->get_version();
		$template_directory = get_template_directory_uri();
		$deps               = array( 'jquery' );

		// The comment-reply script.
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// Ad Blocker Detector.
		if ( ! empty( ahead_get_settings( 'detect_adblocker' ) ) ) {
			wp_enqueue_script( 'AdBlockerDetector', get_template_directory_uri() . '/js/ads.js' );
		}

		// Main theme script.
		wp_register_script( 'ahead_customscript', $template_directory . '/js/ahead-customscripts.js', $deps, $version, true );

		// Localize for Responsive Menu.
		$nav_menu = 'none';
		if ( ! empty( ahead_get_settings( 'dropdown_menu' ) ) ) {
			$nav_menu = 'both';
		} else {
			$nav_menu = 'primary';
		}
		$layout = ahead_get_settings( 'homepage_layout' );
		wp_localize_script( 'ahead_customscript', 'ahead_customscript', array(
			'nav_menu'   => $nav_menu,
			'responsive' => ( empty( ahead_get_settings( 'mts_responsive' ) ) ? false : true ),
			'layout'     => ahead_get_settings( 'header_styles' ),
			'show'       => ahead_get_settings( 'show_top_button' ),
			'icon'       => ahead_get_settings( 'top_button_icon' ),
		) );
		wp_enqueue_script( 'ahead_customscript' );

		// Slider.
		wp_register_script( 'owl-carousel', $template_directory . '/js/owl.carousel.min.js', $deps, $version, true );

		// Animated Single Post or Page header.
		wp_register_script( 'ahead-parallax', $template_directory . '/js/ahead-parallax.js', $deps, $version, true );
		wp_register_script( 'ahead-zoomout', $template_directory . '/js/ahead-zoomout.js', $deps, $version, true );
		if ( is_singular() ) {
			$header_animation = ahead_get_post_header_effect();
			if ( 'parallax' === $header_animation ) {
				wp_enqueue_script( 'ahead-parallax' );
			} elseif ( 'zoomout' === $header_animation ) {
				wp_enqueue_script( 'ahead-zoomout' );
			}
		}

		// Lightbox.
		if ( ahead_get_settings( 'enable_lightbox' ) ) {
			wp_enqueue_script( 'magnificPopup', $template_directory . '/js/jquery.magnific-popup.min.js', $deps, $version, true );
		}

		// Sticky Navigation.
		wp_register_script( 'StickyNav', $template_directory . '/js/sticky.js', $deps, $version, true );
		if ( ! empty( ahead_get_settings( 'sticky_nav' ) ) ) {
			wp_enqueue_script( 'StickyNav' );
		}

		// Ajax Load More and Search Results.
		wp_register_script( 'ahead-ajax', get_template_directory_uri() . '/js/ajax.js', $deps, $version, true );
		wp_register_script( 'historyjs', get_template_directory_uri() . '/js/history.js', $deps, $version, true );
		if ( ! empty( ahead_get_settings( 'mts_pagenavigation_type' ) ) && ahead_get_settings( 'mts_pagenavigation_type' ) >= 2 && ! is_singular() ) {
			wp_enqueue_script( 'ahead-ajax' );
			wp_enqueue_script( 'historyjs' );

			// Add parameters for the JS.
			global $wp_query;
			$max      = $wp_query->max_num_pages;
			$paged    = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
			$autoload = ( '3' === ahead_get_settings( 'mts_pagenavigation_type' ) );
			wp_localize_script( 'ahead-ajax', 'ahead_ajax_loadposts', array(
				'startPage'     => $paged,
				'maxPages'      => $max,
				'nextLink'      => next_posts( $max, false ),
				'autoLoad'      => $autoload,
				'i18n_loadmore' => __( 'Load More Posts', 'ahead' ),
				'i18n_loading'  => __( 'Loading...', 'ahead' ),
				'i18n_nomore'   => __( 'No more posts.', 'ahead' ),
			) );
		}
		if ( ! empty( ahead_get_settings( 'mts_ajax_search' ) ) ) {
			wp_enqueue_script( 'ahead-ajax' );
			wp_localize_script( 'ahead-ajax', 'ahead_ajax_search', array(
				'url'         => admin_url( 'admin-ajax.php' ),
				'ajax_search' => '1',
			));
		}
	}

	/**
	 * Generate needed font
	 *
	 * @return void
	 */
	public function font_styles() {

		$link = get_transient( 'ahead_dynamic_css_typography_link' );
		if ( false === $link ) {
			$fonts = $this->get_google_fonts();

			// If we don't have any fonts then we can exit.
			if ( empty( $fonts ) ) {
				return;
			}

			// Get font-family + subsets.
			$link_fonts = array();
			foreach ( $fonts as $font => $variants ) {

				$variants = implode( ',', $variants );

				$link_font = str_replace( ' ', '+', $font );
				if ( ! empty( $variants ) ) {
					$link_font .= ':' . $variants;
				}
				$link_fonts[] = $link_font;
			}

			$subsets = ahead_get_settings( 'typography-subsets', array() );
			$link    = add_query_arg( array(
				'family'  => str_replace( '%2B', '+', urlencode( implode( '|', $link_fonts ) ) ),
				'subset'  => urlencode( implode( ',', $subsets ) ),
				'display' => 'swap',
			), 'https://fonts.googleapis.com/css' );

			set_transient( 'ahead_dynamic_css_typography_link', $link );
		}

		// Enqueue it.
		wp_enqueue_style( 'ahead_google_fonts', $link, array(), null );
	}

	/**
	 * Get typography from theme options
	 *
	 * @return array
	 */
	private function get_google_fonts() {

		$fonts      = array();
		$collection = (array) ahead_get_settings( 'typography-collections', array() );

		$opts = array(
			'ahead_logo',
			'ahead_footer_logo',
			'primary_navigation_font',
			'content_font',
			'pagination_font',
			'loadmore_font',
			'archive_post_title_font',
			'archive_post_excerpt_font',
			'archive_post_category_font',
			'archive_meta_info_font',
			'breadcrumb_font',
			'tags_font',
			'single_title_font',
			'mts_single_category_meta_font',
			'mts_single_meta_info_font',
			'single_page_titles_font',
			'pages_title_font',
			'single_subscribe_title_font',
			'single_subscribe_text_font',
			'single_subscribe_input_font',
			'single_subscribe_submit_font',
			'single_subscribe_small_text_font',
			'authorbox_title_font',
			'authorbox_author_name_font',
			'authorbox_text_font',
			'sidebar_title_font',
			'sidebar_font',
			'sidebar_links_widgets',
			'sidebar_post_title',
			'sidebar_large_post_title',
			'sidebar_postinfo_font',
			'subscribe_widget_title_font',
			'sidebar_fields_font',
			'subscribe_widget_text_font',
			'subscribe_widget_submit_font',
			'subscribe_widget_small_text_font',
			'footer_nav_font',
			'top_footer_title_font',
			'top_footer_font',
			'footer_links_widgets',
			'top_footer_post_title',
			'footer_large_post_title',
			'top_footer_meta_font',
			'footer_subscribe_widget_title_font',
			'footer_fields_font',
			'footer_subscribe_widget_text_font',
			'footer_subscribe_widget_submit_font',
			'footer_subscribe_widget_small_text_font',
			'copyrights_font',
			'fields_font',
			'buttons_font',
			'h1_headline',
			'h2_headline',
			'h3_headline',
			'h4_headline',
			'h5_headline',
			'h6_headline',
			'related_posts_font',
			'related_post_category_font',
			'related_posts_meta_font',
			'related_posts_text_font',
		);

		// Dynamic Tab Fonts.
		$features = ahead_get_settings( 'featured_categories' );
		foreach ( $features as $feature ) {
			if ( ! isset( $feature['unique_id'] ) ) {
				continue;
			}
			$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
			//Typography Settings
			$opts[] = 'featured_category_title_font_' . $feature['unique_id'];
			$opts[] = 'post_button_font_' . $feature['unique_id'];
			$opts[] = 'post_category_font_' . $feature['unique_id'];
			$opts[] = 'meta_info_font_' . $feature['unique_id'];
			$opts[] = 'post_title_font_' . $feature['unique_id'];
			$opts[] = 'post_excerpt_font_' . $feature['unique_id'];
			if ( 'layout-1' === $posts_layout || 'layout-2' === $posts_layout ) {
				$opts[] = 'post_big_title_font_' . $feature['unique_id'];
			}
			if ( 'layout-2' === $posts_layout ) {
				$opts[] = 'post_big_excerpt_font_' . $feature['unique_id'];
			}
		}

		foreach ( $opts as $key ) {
			$val = ahead_get_settings( $key, false );

			if ( $val ) {

				// Add to collection.
				$collection[] = $val;
			}
		}

		foreach ( (array) $collection as $font ) {

			$variant = '';

			if ( isset( $font['css-selectors'] ) && empty( trim( $font['css-selectors'] ) ) ) {
				continue;
			}

			if ( empty( $font['font-family'] ) ) {
				continue;
			}

			$variant = empty( $font['font-weight'] ) || 'normal' === $font['font-weight'] ? '400' : $font['font-weight'];

			// Add "i" to font-weight to make italics properly load.
			if ( isset( $font['font-style'] ) && 'italic' === $font['font-style'] ) {
				$variant .= 'i';
			}

			// Add the requested google-font.
			if ( ! isset( $fonts[ $font['font-family'] ] ) ) {
				$fonts[ $font['font-family'] ] = array();
			}
			if ( ! in_array( $variant, $fonts[ $font['font-family'] ], true ) ) {
				$fonts[ $font['font-family'] ][] = $variant;
			}
		}

		return $fonts;
	}

	/**
	 * Add async to ahead javascript file for performance
	 *
	 * @param string $tag    The script tag.
	 * @param string $handle The script handle.
	 */
	public function add_async( $tag, $handle ) {

		$to_match = array( 'ahead' );
		return in_array( $handle, $to_match ) ? str_replace( ' src', ' async src', $tag ) : $tag;
	}

	/**
	 * Remove version param from script or style source url
	 *
	 * @param  string $src Script loader source path.
	 */
	public function remove_version( $src ) {

		$parts = explode( '?ver', $src );
		return $parts[0];
	}

	/**
	 * Remove WooCommerce Scripts and Styles from unneeded pages.
	 */
	public function remove_woocommerce_scripts() {

		// First check that woo exists to prevent fatal errors.
		if ( function_exists( 'is_woocommerce' ) ) {

			// Dequeue scripts and styles.
			if ( ! is_woocommerce() && ! is_cart() && ! is_checkout() && ! is_account_page() ) {
				wp_dequeue_script( 'ahead-woocommerce' );
				wp_dequeue_style( 'woocommerce-layout' );
				wp_dequeue_style( 'woocommerce-smallscreen' );
				wp_dequeue_style( 'woocommerce-general' );
				wp_dequeue_style( 'wc-bto-styles' );
				wp_dequeue_script( 'wc-add-to-cart' );
				wp_dequeue_script( 'wc-cart-fragments' );
				wp_dequeue_script( 'woocommerce' );
				wp_dequeue_script( 'jquery-blockui' );
				wp_dequeue_script( 'jquery-placeholder' );
			}
		}
	}
}

/**
 * Init
 */
new Ahead_Scripts;
