<?php
/**
 * Archive Pages
 *
 * @package Ahead
 */

$menus['blog-archive'] = array(
	'icon'  => 'fa-archive',
	'title' => esc_html__( 'Archives', 'ahead' ),
	'desc'  => esc_html__( 'From here, you can control the elements of the archive pages.', 'ahead' ),
);

// Dependency check that Category is enable.
$archive_post_category_dependency = array(
	'relation' => 'and',
	array(
		'field'      => 'archive_post_category',
		'value'      => '1',
		'comparison' => '==',
	),
);

$sections['blog-archive'] = array(
	array(
		'id'       => 'archive_excerpt',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Excerpt Length', 'magnus' ),
		'sub_desc' => esc_html__( 'Max lenght is 55 Words.', 'magnus' ),
		'args'     => array( 'type' => 'number' ),
		'std'      => '15',
	),
	array(
		'id'    => 'archive_post_title_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Archive Post Font', 'ahead' ),
	),
	array(
		'id'    => 'archive_post_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Post Title Font', 'ahead' ),
		'std'   => array(
			'preview-text'   => 'Post Title Font',
			'preview-color'  => 'light',
			'font-family'    => 'Public Sans',
			'font-weight'    => '300',
			'font-size'      => '20px',
			'line-height'    => '1.2',
			'color'          => '#151942',
			'letter-spacing' => ahead_letter_spacing( 20, 16 ),
			'css-selectors'  => '.latestPost .title a, .archive .latestPost .title a, .search .latestPost .title a, .archive [class^="more-page"] .latestPost .title a, .search [class^="more-page"] .latestPost .title a',
		),
	),
	array(
		'id'    => 'archive_post_excerpt_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Post Excerpt Font', 'ahead' ),
		'std'   => array(
			'preview-text'   => 'Post Excerpt Font',
			'preview-color'  => 'light',
			'font-family'    => 'Public Sans',
			'font-weight'    => '400',
			'font-size'      => '15px',
			'line-height'    => ahead_line_height( 15, 22 ),
			'color'          => '#151942',
			'letter-spacing' => ahead_letter_spacing( 15, 18 ),
			'css-selectors'  => '.archive .latestPost .front-view-content, .search .latestPost .front-view-content, .archive [class^="more-page"] .latestPost .front-view-content, .search [class^="more-page"] .latestPost .front-view-content',
		),
	),
	array(
		'id'    => 'archive_meta_info_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Archive Meta Info', 'ahead' ),
	),
	array(
		'id'       => 'archive_post_category',
		'type'     => 'switch',
		'title'    => esc_html__( 'Enable/Disable Category', 'ahead' ),
		'sub_desc' => esc_html__( 'Use this button to show or hide category.', 'ahead' ),
		'std'      => '1',
	),
	array(
		'id'         => 'archive_post_category_type',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Categories', 'ahead' ),
		'options'    => array(
			'0' => esc_html__( 'First Category', 'ahead' ),
			'1' => esc_html__( 'ALL Categories', 'ahead' ),
		),
		'sub_desc'   => esc_html__( 'Show only first category or all the categories of post from here.', 'ahead' ),
		'std'        => '0',
		'dependency' => $archive_post_category_dependency,
	),
	array(
		'id'         => 'archive_post_category_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Category Typography', 'ahead' ),
		'color'      => false,
		'std'        => array(
			'preview-text'   => 'Category Font',
			'preview-color'  => 'light',
			'font-family'    => 'Public Sans',
			'font-weight'    => '300',
			'font-size'      => '8px',
			'margin-bottom'  => '10px',
			'additional-css' => 'text-transform: uppercase;',
			'letter-spacing' => ahead_letter_spacing( 8, 250 ),
			'css-selectors'  => '.archive .latestPost .thecategory a, .search .latestPost .thecategory a',
		),
		'dependency' => $archive_post_category_dependency,
	),
	array(
		'id'       => 'archive_post_meta_info',
		'type'     => 'layout2',
		'title'    => esc_html__( 'Post Meta Info', 'ahead' ),
		'sub_desc' => esc_html__( 'Organize how you want the post meta info to appear on archive pages', 'ahead' ),
		'options'  => array(
			'enabled'  => array(
				'author' => array(
					'label'     => esc_html__( 'Author Name', 'ahead' ),
					'subfields' => array(
						array(
							'id'    => 'archive_meta_info_author_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'ahead' ),
						),
					),
				),
				'date'   => array(
					'label'     => esc_html__( 'Date', 'ahead' ),
					'subfields' => array(
						array(
							'id'    => 'archive_meta_info_date_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'ahead' ),
						),
					),
				),
			),
			'disabled' => array(
				'comment' => array(
					'label'     => esc_html__( 'Comment Count', 'ahead' ),
					'subfields' => array(
						array(
							'id'    => 'archive_meta_info_comment_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'ahead' ),
						),
					),
				),
			),
		),
		'std'      => array(
			'enabled'  => array(
				'author' => array(
					'label'     => esc_html__( 'Author Name', 'ahead' ),
					'subfields' => array(
						array(
							'id'    => 'archive_meta_info_author_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'ahead' ),
						),
					),
				),
				'date'   => array(
					'label'     => esc_html__( 'Date', 'ahead' ),
					'subfields' => array(
						array(
							'id'    => 'archive_meta_info_date_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'ahead' ),
						),
					),
				),
			),
			'disabled' => array(
				'comment' => array(
					'label'     => esc_html__( 'Comment Count', 'ahead' ),
					'subfields' => array(
						array(
							'id'    => 'archive_meta_info_comment_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'ahead' ),
						),
					),
				),
			),
		),
	),
	array(
		'id'    => 'archive_meta_info_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Post Meta Info Typography', 'ahead' ),
		'std'   => array(
			'preview-text'   => 'Post Meta Info Font',
			'preview-color'  => 'light',
			'font-family'    => 'Public Sans',
			'font-weight'    => '300',
			'font-size'      => '13px',
			'margin-top'     => ahead_px2rem( '7px' ),
			'margin-bottom'  => ahead_px2rem( '12px' ),
			'line-height'    => '1',
			'color'          => '#8a8ca0',
			'letter-spacing' => ahead_letter_spacing( 13, 38 ),
			'css-selectors'  => '.archive .latestPost .post-info, .archive .latestPost .post-info a, .search .latestPost .post-info, .search .latestPost .post-info a',
		),
	),
);
