<?php
/**
 * HomePage Posts
 *
 * @package Ahead
 */

$features = ahead_get_settings( 'featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = array(
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'ahead' ) ), $title ),
	);

	// Dependency check that Title is enable.
	$post_title_dependency = array(
		'field'      => 'featured_category_title_' . $unique_id,
		'value'      => '1',
		'comparison' => '==',
	);

	// Dependency check that View More is enable.
	$view_more_dependency = array(
		'field'      => 'post_button_' . $unique_id,
		'value'      => '1',
		'comparison' => '==',
	);

	// Dependency check that Category is enable.
	$post_category_dependency = array(
		'relation' => 'and',
		array(
			'field'      => 'post_category_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	// Dependency check that excerpt is enable.
	$post_big_excerpt_dependency = array(
		'relation' => 'and',
		array(
			'field'      => 'big_post_excerpt_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$post_excerpt_dependency = array(
		'relation' => 'and',
		array(
			'field'      => 'post_excerpt_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$sections[ 'blog-' . $unique_id ] = array(

		/**
		 * Layout Default Settings
		 *
		 * @package Ahead
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'ahead' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'ahead' ),
			'std'      => '0',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => ahead_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#151942',
				'letter-spacing' => ahead_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_button_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'View More Button', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide view more button.', 'ahead' ),
			'std'      => '0',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_button_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'View More Typography', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'View More Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '13px',
				'color'          => '#a3a4ad',
				'letter-spacing' => ahead_letter_spacing( 13, 38 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .view-more a',
			),
			'dependency' => array(
				'relation' => 'and',
				$view_more_dependency,
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_heading_' . $unique_id,
			'type'       => 'heading',
			'title'      => esc_html__( 'Post Title Container', 'ahead' ),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'ahead' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'ahead' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => ahead_px2rem( '30px' ),
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'ahead' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'ahead' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'ahead' ),
			'sub_desc'   => esc_html__( 'Select border', 'ahead' ),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_ad_management_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'First Post Ad', 'ahead' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_first_post_adcode',
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'First Post Ad', 'ahead' ),
			'sub_desc' => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads at the place of First Post. Recommended width 730px.', 'ahead' ),
		) : null,

		// Meta info.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'ahead' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_category_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Category', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide category.', 'ahead' ),
			'std'      => '1',
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_category_type_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Categories', 'ahead' ),
			'options'    => array(
				'0' => esc_html__( 'First Category', 'ahead' ),
				'1' => esc_html__( 'ALL Categories', 'ahead' ),
			),
			'sub_desc'   => esc_html__( 'Show only first category or all the categories of post from here.', 'ahead' ),
			'std'        => '0',
			'dependency' => $post_category_dependency,
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_category_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Category Typography', 'ahead' ),
			'color'      => false,
			'std'        => array(
				'preview-text'   => 'Category Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '8px',
				'margin-bottom'  => '10px',
				'additional-css' => 'text-transform: uppercase;',
				'letter-spacing' => ahead_letter_spacing( 8, 250 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thecategory a',
			),
			'dependency' => $post_category_dependency,
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'ahead' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'ahead' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '13px',
				'margin-top'     => ahead_px2rem( '7px' ),
				'margin-bottom'  => ahead_px2rem( '12px' ),
				'line-height'    => '1',
				'color'          => '#8a8ca0',
				'letter-spacing' => ahead_letter_spacing( 13, 38 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Post Container.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'ahead' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'ahead' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'ahead' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'ahead' ),
			'sub_desc' => esc_html__( 'Select border', 'ahead' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'ahead' ),
			'sub_desc' => esc_html__( 'Post margin.', 'ahead' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => ahead_px2rem( '75px' ),
				'bottom' => ahead_px2rem( '20px' ),
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'ahead' ),
			'sub_desc' => esc_html__( 'Post padding.', 'ahead' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => ahead_px2rem( '20px' ),
				'line-height'    => '1.2',
				'color'          => '#151942',
				'letter-spacing' => ahead_letter_spacing( 20, 16 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Post Excerpt Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '400',
				'font-size'      => ahead_px2rem( '15px' ),
				'line-height'    => ahead_line_height( 15, 22 ),
				'color'          => '#151942',
				'letter-spacing' => ahead_letter_spacing( 15, 18 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout 1 Settings
		 *
		 * @package Ahead
		 */

		// Section Title.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'ahead' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'ahead' ),
			'std'      => '1',
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => ahead_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#151942',
				'letter-spacing' => ahead_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_button_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'View More Button', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide view more button.', 'ahead' ),
			'std'      => '1',
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_button_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'View More Typography', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'View More Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '13px',
				'color'          => '#a3a4ad',
				'letter-spacing' => ahead_letter_spacing( 13, 38 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .view-more a',
			),
			'dependency' => array(
				'relation' => 'and',
				$view_more_dependency,
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'featured_category_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Title Container', 'ahead' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'ahead' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'ahead' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => ahead_px2rem( '22px' ),
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'ahead' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'ahead' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'ahead' ),
			'sub_desc'   => esc_html__( 'Select border', 'ahead' ),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		// Meta info.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'ahead' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_category_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Category', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide category.', 'ahead' ),
			'std'      => '1',
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_category_type_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Categories', 'ahead' ),
			'options'    => array(
				'0' => esc_html__( 'First Category', 'ahead' ),
				'1' => esc_html__( 'ALL Categories', 'ahead' ),
			),
			'sub_desc'   => esc_html__( 'Show only first category or all the categories of post from here.', 'ahead' ),
			'std'        => '0',
			'dependency' => $post_category_dependency,
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_category_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Category Typography', 'ahead' ),
			'color'      => false,
			'std'        => array(
				'preview-text'   => 'Category Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '8px',
				'margin-bottom'  => ahead_px2rem( '15px' ),
				'additional-css' => 'text-transform: uppercase;',
				'letter-spacing' => ahead_letter_spacing( 8, 250 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thecategory a',
			),
			'dependency' => $post_category_dependency,
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'ahead' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'ahead' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '13px',
				'margin-top'     => ahead_px2rem( '10px' ),
				'margin-bottom'  => '0',
				'line-height'    => '1',
				'color'          => '#ffffff',
				'letter-spacing' => ahead_letter_spacing( 13, 38 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Post Container.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'ahead' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'ahead' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'ahead' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'ahead' ),
			'sub_desc' => esc_html__( 'Select border', 'ahead' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'ahead' ),
			'sub_desc' => esc_html__( 'Post margin.', 'ahead' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => ahead_px2rem( '72px' ),
				'bottom' => '0',
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'ahead' ),
			'sub_desc' => esc_html__( 'Post padding.', 'ahead' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_big_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Big Post Title Font', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Big Post Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => ahead_px2rem( '32px' ),
				'line-height'    => '1.2',
				'color'          => '#ffffff',
				'letter-spacing' => ahead_letter_spacing( 32, 16 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost.big .title a',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => ahead_px2rem( '20px' ),
				'line-height'    => '1.2',
				'color'          => '#ffffff',
				'letter-spacing' => ahead_letter_spacing( 20, 16 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		/**
		 * Layout 2 Settings
		 *
		 * @package Ahead
		 */

		// Section Title.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'ahead' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'ahead' ),
			'std'      => '1',
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => ahead_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#151942',
				'letter-spacing' => ahead_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_button_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'View More Button', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide view more button.', 'ahead' ),
			'std'      => '1',
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_button_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'View More Typography', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'View More Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '13px',
				'color'          => '#a3a4ad',
				'letter-spacing' => ahead_letter_spacing( 13, 38 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .view-more a',
			),
			'dependency' => array(
				'relation' => 'and',
				$view_more_dependency,
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'featured_category_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Title Container', 'ahead' ),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'ahead' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'ahead' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => ahead_px2rem( '30px' ),
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'ahead' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'ahead' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'ahead' ),
			'sub_desc'   => esc_html__( 'Select border', 'ahead' ),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		// Meta info.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'ahead' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_category_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Category', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide category.', 'ahead' ),
			'std'      => '1',
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_category_type_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Categories', 'ahead' ),
			'options'    => array(
				'0' => esc_html__( 'First Category', 'ahead' ),
				'1' => esc_html__( 'ALL Categories', 'ahead' ),
			),
			'sub_desc'   => esc_html__( 'Show only first category or all the categories of post from here.', 'ahead' ),
			'std'        => '0',
			'dependency' => $post_category_dependency,
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_category_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Category Typography', 'ahead' ),
			'color'      => false,
			'std'        => array(
				'preview-text'   => 'Category Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '8px',
				'margin-bottom'  => ahead_px2rem( '13px' ),
				'additional-css' => 'text-transform: uppercase;',
				'letter-spacing' => ahead_letter_spacing( 8, 250 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thecategory a',
			),
			'dependency' => $post_category_dependency,
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'ahead' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'ahead' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '13px',
				'margin-top'     => ahead_px2rem( '10px' ),
				'margin-bottom'  => ahead_px2rem( '7px' ),
				'line-height'    => '1',
				'color'          => '#8a8ca0',
				'letter-spacing' => ahead_letter_spacing( 13, 38 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Post Container.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'ahead' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'ahead' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'ahead' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'ahead' ),
			'sub_desc' => esc_html__( 'Select border', 'ahead' ),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'ahead' ),
			'sub_desc' => esc_html__( 'Post margin.', 'ahead' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => ahead_px2rem( '42px' ),
				'bottom' => ahead_px2rem( '70px' ),
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'ahead' ),
			'sub_desc' => esc_html__( 'Post padding.', 'ahead' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_big_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Big Post Title Font', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Big Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => ahead_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#151942',
				'letter-spacing' => ahead_letter_spacing( 24, 16 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost.big .title a',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => ahead_px2rem( '20px' ),
				'line-height'    => '1.2',
				'color'          => '#151942',
				'letter-spacing' => ahead_letter_spacing( 20, 16 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'big_post_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Big Posts Excerpts', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide big post excerpt.', 'ahead' ),
			'std'      => '0',
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_big_excerpt_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Big Post Excerpt Font', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'Big Post Excerpt Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '400',
				'font-size'      => ahead_px2rem( '18px' ),
				'line-height'    => ahead_line_height( 16, 24 ),
				'color'          => '#181b43',
				'letter-spacing' => ahead_letter_spacing( 16, 18 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost.big .front-view-content',
			),
			'dependency' => $post_big_excerpt_dependency,
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Post Excerpts', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide small post excerpt.', 'ahead' ),
			'std'      => '0',
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_excerpt_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Post Excerpt Font', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'Post Excerpt Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '400',
				'font-size'      => '14px',
				'line-height'    => ahead_line_height( 14, 22 ),
				'color'          => '#181b43',
				'letter-spacing' => ahead_letter_spacing( 14, 18 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
			'dependency' => $post_excerpt_dependency,
		) : null,

		/**
		 * Layout 3 Settings
		 *
		 * @package Ahead
		 */

		// Section Title.
		( 'layout-3' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'ahead' ),
		) : null,

		( 'layout-3' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'ahead' ),
			'std'      => '1',
		) : null,
		( 'layout-3' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => ahead_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#f5f5f5',
				'letter-spacing' => ahead_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'layout-3' === $posts_layout ) ? array(
			'id'       => 'post_button_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'View More Button', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide view more button.', 'ahead' ),
			'std'      => '1',
		) : null,
		( 'layout-3' === $posts_layout ) ? array(
			'id'         => 'post_button_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'View More Typography', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'View More Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '13px',
				'color'          => '#a8a8a9',
				'letter-spacing' => ahead_letter_spacing( 13, 38 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .view-more a',
			),
			'dependency' => array(
				'relation' => 'and',
				$view_more_dependency,
			),
		) : null,
		( 'layout-3' === $posts_layout ) ? array(
			'id'    => 'featured_category_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Title Container', 'ahead' ),
		) : null,
		( 'layout-3' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'ahead' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'ahead' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => ahead_px2rem( '30px' ),
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		( 'layout-3' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'ahead' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'ahead' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		( 'layout-3' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'ahead' ),
			'sub_desc'   => esc_html__( 'Select border', 'ahead' ),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		// Meta info.
		( 'layout-3' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'ahead' ),
		) : null,

		( 'layout-3' === $posts_layout ) ? array(
			'id'       => 'post_category_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Category', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide category.', 'ahead' ),
			'std'      => '0',
		) : null,

		( 'layout-3' === $posts_layout ) ? array(
			'id'         => 'post_category_type_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Categories', 'ahead' ),
			'options'    => array(
				'0' => esc_html__( 'First Category', 'ahead' ),
				'1' => esc_html__( 'ALL Categories', 'ahead' ),
			),
			'sub_desc'   => esc_html__( 'Show only first category or all the categories of post from here.', 'ahead' ),
			'std'        => '0',
			'dependency' => $post_category_dependency,
		) : null,

		( 'layout-3' === $posts_layout ) ? array(
			'id'         => 'post_category_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Category Typography', 'ahead' ),
			'color'      => false,
			'std'        => array(
				'preview-text'   => 'Category Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '8px',
				'margin-bottom'  => '10px',
				'additional-css' => 'text-transform: uppercase;',
				'letter-spacing' => ahead_letter_spacing( 8, 250 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thecategory a',
			),
			'dependency' => $post_category_dependency,
		) : null,

		( 'layout-3' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'ahead' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'ahead' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-3' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '11px',
				'margin-top'     => ahead_px2rem( '10px' ),
				'margin-bottom'  => '0',
				'line-height'    => '1',
				'color'          => '#ffffff',
				'letter-spacing' => ahead_letter_spacing( 11, 38 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Post Container.
		( 'layout-3' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'ahead' ),
		) : null,

		( 'layout-3' === $posts_layout ) ? array(
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'ahead' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'ahead' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#1d1d22',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'layout-3' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'ahead' ),
			'sub_desc' => esc_html__( 'Select border', 'ahead' ),
		) : null,
		( 'layout-3' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'ahead' ),
			'sub_desc' => esc_html__( 'Post margin.', 'ahead' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => ahead_px2rem( '80px' ),
			),
		) : null,
		( 'layout-3' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'ahead' ),
			'sub_desc' => esc_html__( 'Post padding.', 'ahead' ),
			'std'      => array(
				'left'   => '0',
				'top'    => ahead_px2rem( '60px' ),
				'right'  => '0',
				'bottom' => ahead_px2rem( '30px' ),
			),
		) : null,

		( 'layout-3' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '15px',
				'line-height'    => '1.2',
				'color'          => '#ffffff',
				'letter-spacing' => ahead_letter_spacing( 15, 16 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		/**
		 * Layout 4 Settings
		 *
		 * @package Ahead
		 */

		// Section Title.
		( 'layout-4' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'ahead' ),
		) : null,

		( 'layout-4' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'ahead' ),
			'std'      => '1',
		) : null,
		( 'layout-4' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => ahead_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#151942',
				'letter-spacing' => ahead_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'layout-4' === $posts_layout ) ? array(
			'id'       => 'post_button_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'View More Button', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide view more button.', 'ahead' ),
			'std'      => '1',
		) : null,
		( 'layout-4' === $posts_layout ) ? array(
			'id'         => 'post_button_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'View More Typography', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'View More Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '13px',
				'color'          => '#a3a4ad',
				'letter-spacing' => ahead_letter_spacing( 13, 38 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .view-more a',
			),
			'dependency' => array(
				'relation' => 'and',
				$view_more_dependency,
			),
		) : null,
		( 'layout-4' === $posts_layout ) ? array(
			'id'    => 'featured_category_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Title Container', 'ahead' ),
		) : null,
		( 'layout-4' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'ahead' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'ahead' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => ahead_px2rem( '30px' ),
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		( 'layout-4' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'ahead' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'ahead' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		( 'layout-4' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'ahead' ),
			'sub_desc'   => esc_html__( 'Select border', 'ahead' ),
			'dependency' => array(
				'relation' => 'or',
				$post_title_dependency,
				$view_more_dependency,
			),
		) : null,
		// Meta info.
		( 'layout-4' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'ahead' ),
		) : null,

		( 'layout-4' === $posts_layout ) ? array(
			'id'       => 'post_category_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Category', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide category.', 'ahead' ),
			'std'      => '1',
		) : null,

		( 'lauout-4' === $posts_layout ) ? array(
			'id'         => 'post_category_type_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Categories', 'ahead' ),
			'options'    => array(
				'0' => esc_html__( 'First Category', 'ahead' ),
				'1' => esc_html__( 'ALL Categories', 'ahead' ),
			),
			'sub_desc'   => esc_html__( 'Show only first category or all the categories of post from here.', 'ahead' ),
			'std'        => '0',
			'dependency' => $post_category_dependency,
		) : null,

		( 'layout-4' === $posts_layout ) ? array(
			'id'         => 'post_category_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Category Typography', 'ahead' ),
			'color'      => false,
			'std'        => array(
				'preview-text'   => 'Category Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '8px',
				'margin-bottom'  => '10px',
				'additional-css' => 'text-transform: uppercase;',
				'letter-spacing' => ahead_letter_spacing( 8, 250 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thecategory a',
			),
			'dependency' => $post_category_dependency,
		) : null,

		( 'layout-4' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'ahead' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'ahead' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'ahead' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'ahead' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-4' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => '13px',
				'margin-top'     => ahead_px2rem( '7px' ),
				'margin-bottom'  => ahead_px2rem( '12px' ),
				'line-height'    => '1',
				'color'          => '#8a8ca0',
				'letter-spacing' => ahead_letter_spacing( 13, 38 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Post Container.
		( 'layout-4' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'ahead' ),
		) : null,

		( 'layout-4' === $posts_layout ) ? array(
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'ahead' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'ahead' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'layout-4' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'ahead' ),
			'sub_desc' => esc_html__( 'Select border', 'ahead' ),
		) : null,
		( 'layout-4' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'ahead' ),
			'sub_desc' => esc_html__( 'Post margin.', 'ahead' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '0',
			),
		) : null,
		( 'layout-4' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'ahead' ),
			'sub_desc' => esc_html__( 'Post padding.', 'ahead' ),
			'std'      => array(
				'left'   => '0',
				'top'    => ahead_px2rem( '20px' ),
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-4' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'ahead' ),
			'std'   => array(
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '300',
				'font-size'      => ahead_px2rem( '20px' ),
				'line-height'    => '1.2',
				'color'          => '#181b43',
				'letter-spacing' => ahead_letter_spacing( 20, 16 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'layout-4' === $posts_layout ) ? array(
			'id'       => 'post_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Post Excerpts', 'ahead' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide small post excerpt.', 'ahead' ),
			'std'      => '0',
		) : null,

		( 'layout-4' === $posts_layout ) ? array(
			'id'         => 'post_excerpt_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Post Excerpt Font', 'ahead' ),
			'std'        => array(
				'preview-text'   => 'Post Excerpt Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '400',
				'font-size'      => '14px',
				'line-height'    => ahead_line_height( 14, 21 ),
				'color'          => '#181b43',
				'letter-spacing' => ahead_letter_spacing( 14, 18 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
			'dependency' => $post_excerpt_dependency,
		) : null,

		/**
		 * Layout HTML Settings
		 *
		 * @package Ahead
		 */
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_layout_html_' . $unique_id,
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'HTML Post', 'ahead' ),
			'sub_desc' => esc_html__( 'Paste your HTML, Text or other code here.', 'ahead' ),
			'std'      => '<img src="' . get_template_directory_uri() . '/images/banner.jpg">',
		) : null,
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'ahead' ),
			'sub_desc' => esc_html__( 'Post margin.', 'ahead' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => ahead_px2rem( '108px' ),
			),
		) : null,
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'ahead' ),
			'sub_desc' => esc_html__( 'Post padding.', 'ahead' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

	);
endforeach;
